@@ -252,8 +252,8 @@ sleepwalk <- function( embeddings, featureMatrices = NULL, maxdists = NULL, poin
   
   if(is.null(saveToFile)) {
     jrc::openPage( useViewer = FALSE, 
-                   rootDirectory = system.file( package="sleepwalk" ), 
-                   startPage = paste0("sleepwalk_", mode, ".html"), ... )
+                   rootDirectory = system.file( package="sleepwalk" ),
+                   startPage = paste0(system.file( package="sleepwalk" ),"/sleepwalk_", mode, ".html"), ... )
     jrc::limitStorage(n = 0)
     jrc::allowFunctions(c("message", ".slw$on_selection"))
     jrc::allowVariables(c("embs", "dists", "pointSize", "maxdists", "titles", "finished"))
